@@ -29,7 +29,12 @@ def suggest_type(full_text, text_before_cursor):
         last_token = parsed[0].token_prev(len(parsed[0].tokens))
         last_token = last_token.value if last_token else ''
 
-    if last_token.lower() in ('set', 'by'):
+    def is_function_word(word):
+        return word and len(word) > 1 and word[-1] == '('
+
+    if is_function_word(word_before_cursor):
+        return ('columns', extract_tables(full_text))
+    elif last_token.lower() in ('set', 'by', 'distinct'):
         return ('columns', extract_tables(full_text))
     elif last_token.lower() in ('select', 'where', 'having'):
         return ('columns-and-functions', extract_tables(full_text))
